@@ -7,7 +7,8 @@ class DatasetTypes:
     IMAGE_TEXT_MATCHING = 'image_text_matching'
     IMAGE_MATTING = 'image_matting'
     IMAGE_REGRESSION = 'image_regression'
-    VALID_TYPES = [IC_MULTILABEL, IC_MULTICLASS, OD, MULTITASK, IMCAP, IMAGE_TEXT_MATCHING, IMAGE_MATTING, IMAGE_REGRESSION]
+    IMAGE_RETRIEVAL = "image_retrieval"
+    VALID_TYPES = [IC_MULTILABEL, IC_MULTICLASS, OD, MULTITASK, IMCAP, IMAGE_TEXT_MATCHING, IMAGE_MATTING, IMAGE_REGRESSION, IMAGE_RETRIEVAL]
 
     @staticmethod
     def is_classification(dataset_type):
